#! /bin/bash

# Installation script for MPI Link-Checker (TM)
# Copyright 2014 by Microway, Inc.

# ======================================================================

# Change this if necessary

INSTALL_DIR="/usr/local/microway"

# ======================================================================

# Don't change this

REQUIRED_USER="root"

# ======================================================================

# Greeting

echo
echo MPI Link-Checker Installation Script
echo "Part 2 (MPI part)"
echo
echo This script should be run on the head node of the MPI cluster
echo
echo "MPI Link-Checker (TM)"
echo Copyright 2014 by Microway, Inc.
echo

# ======================================================================

# Check that installer is root

if [ "$USER" != "$REQUIRED_USER" ] ; then
  echo You must be logged in as $REQUIRED_USER to install InfiniScope.
  exit 126
fi

# ======================================================================


# ======================================================================

# Make installation directory if necessary

if [ ! -d "$INSTALL_DIR" ] ; then
  if [ -f "$INSTALL_DIR" ] ; then
    echo File $INSTALL_DIR exists, but is not a directory
    exit 65
  else
    echo Making directory $INSTALL_DIR
    mkdir -p $INSTALL_DIR
  fi
fi

# ======================================================================

# Install MPI portion
# DO THIS ON THE MPI HOST, NOT THE GUI HOST

# ======================================================================

#license_manager needed for ascii mode support
cp Makefile.mpilc  $INSTALL_DIR
install license_manager -o root -m 4755 $INSTALL_DIR

install mpilc.c -o root -g root -m 644 $INSTALL_DIR
mpicc -o $INSTALL_DIR/mpilc $INSTALL_DIR/mpilc.c
chmod 755  $INSTALL_DIR/mpilc

#handle automatic distribution to compute nodes on Microway clusters
rcom="notfound"
rcpf="notfound"
[ -f /usr/local/bin/rcom-nodes ] && rcom=/usr/local/bin/rcom-nodes
[ -f /usr/local/bin/scom-nodes ] && rcom=/usr/local/bin/scom-nodes
[ -f /usr/local/bin/rcpf-nodes ] && rcpf=/usr/local/bin/rcpf-nodes
[ -f /usr/local/bin/scpf-nodes ] && rcpf=/usr/local/bin/scpf-nodes
if [ $rcpf != "notfound" -a $rcom != "notfound" ] ; then  #Microway utils found, provide option to install to nodes
  echo
  read -p "Would you like to automaticaly distribute the MPI portion to the nodes? (Y/n)"
  if [[ "$REPLY" == [nN]* ]] ; then
    echo "You must create $INSTALL_DIR on all nodes and distribute a copy of mpilc to it before running Link Checker"
    exit 0
  fi
  $rcom mkdir -p $INSTALL_DIR
  $rcpf $INSTALL_DIR/mpilc $INSTALL_DIR
else
  echo
  echo "Microway cluster scripts (rcom/scom and rcpf/scpf) not found."
  echo "Manual distribution of mpilc to the compute nodes is required"
  echo
  echo "Please ensure $INSTALL_DIR/mpilc is available on all nodes"
  echo "before running Link Checker."
  echo
  echo "If you are running the GUI separately from the cluster,"
  echo "you will probably have to modify the configuration file"
  echo $INSTALL_DIR/link-checker.conf
fi

