#! /bin/bash

# Installation script for MPI Link-Checker (TM)
# Copyright 2014 by Microway, Inc.

# ======================================================================

# Change this if necessary

INSTALL_DIR="/usr/local/microway"

# ======================================================================

# Don't change this

REQUIRED_USER="root"

# ======================================================================

# Greeting

echo "MPI Link-Checker Installation Script"

# ======================================================================

# Check that installer is root

if [ "$USER" != "$REQUIRED_USER" ] ; then
  echo You must be logged in as $REQUIRED_USER to install InfiniScope.
  exit 126
fi

# ======================================================================

# Make installation directory if necessary

if [ ! -d "$INSTALL_DIR" ] ; then
  if [ -f "$INSTALL_DIR" ] ; then
    echo File $INSTALL_DIR exists, but is not a directory
    exit 65
  else
    echo Making directory $INSTALL_DIR
    echo
    mkdir -p $INSTALL_DIR
  fi
fi

# ======================================================================

# Copy files to installation directory

cp lc              $INSTALL_DIR
cp *.html          $INSTALL_DIR
cp *-sequence      $INSTALL_DIR
cp Makefile.mpilc  $INSTALL_DIR

cp *.so*           $INSTALL_DIR
install license_manager -o root -m 4755 $INSTALL_DIR

# ======================================================================

# Copy configuration file to installation directory

cname=$INSTALL_DIR/link-checker.conf
if [ -e $cname ] ; then
 echo Configuration file $cname already exists.
 read -p "Do you want to keep the existing copy? [Yn] "
 if [[ "$REPLY" == [nN]* ]] ; then
  copy=1
  echo Do you want to back up the existing copy
  read -p "    to $cname.bak? [Yn] "
  if [[ "$REPLY" != [nN]* ]] ; then
   cp $cname $cname.bak
  fi
 else
  copy=0
 fi
else
 copy=1
fi

if [ $copy -eq 1 ] ; then
 cp link-checker.conf $INSTALL_DIR
fi

# ======================================================================

# Change owner, group, and protection for all files in installation
# directory

chown root:root $INSTALL_DIR
chown root:root $INSTALL_DIR/*

chmod 755  $INSTALL_DIR
chmod 755  $INSTALL_DIR/lc
chmod 755  $INSTALL_DIR/*wx*
chmod 755  $INSTALL_DIR/*.so
chmod 644  $INSTALL_DIR/link-checker.conf
chmod 644  $INSTALL_DIR/*.html

# ======================================================================

# If key file does not already exist, put an empty one in installation
# directory

keyfile=$INSTALL_DIR/microway.key
if [ ! -e $keyfile ] ; then
  touch $INSTALL_DIR/microway.key
fi
chown root:root $keyfile
chmod 644 $keyfile

# ======================================================================

# Reminders

echo
echo "Part 1 (MPI Link-Checker GUI installation) is complete."
read -p "Continue with MPI collector installation? Only say yes if the GUI also runs MPI. (Y/n)"
if [[ "$REPLY" == [nN]* ]] ; then
  echo "You must run the MPI installer on the head node of the MPI cluster."
  echo "You will need to edit link-checker.conf to configure connecting to it."
  exit 0
fi

# ======================================================================

cp mpilc.c $INSTALL_DIR
chmod 644  $INSTALL_DIR/mpilc.c

mpicc -o $INSTALL_DIR/mpilc $INSTALL_DIR/mpilc.c
chmod 755  $INSTALL_DIR/mpilc
chown root:root $INSTALL_DIR/mpilc.c $INSTALL_DIR/mpilc

# ======================================================================


#handle automatic distribution to compute nodes on Microway clusters
rcom="notfound"
rcpf="notfound"
[ -f /usr/local/bin/rcom-nodes ] && rcom=/usr/local/bin/rcom-nodes
[ -f /usr/local/bin/scom-nodes ] && rcom=/usr/local/bin/scom-nodes
[ -f /usr/local/bin/rcpf-nodes ] && rcpf=/usr/local/bin/rcpf-nodes
[ -f /usr/local/bin/scpf-nodes ] && rcpf=/usr/local/bin/scpf-nodes
if [ $rcpf != "notfound" -a $rcom != "notfound" ] ; then  #Microway utils found, provide option to install to nodes
  echo
  read -p "Would you like to automaticaly distribute the MPI portion to the nodes? (Y/n)"
  if [[ "$REPLY" == [nN]* ]] ; then
    echo "You must create $INSTALL_DIR on all nodes and distribute a copy of mpilc to it before running Link Checker"
    exit 0
  fi
  $rcom mkdir -p $INSTALL_DIR
  $rcpf $INSTALL_DIR/mpilc $INSTALL_DIR
else
  echo
  echo "Microway cluster scripts (rcom/scom and rcpf/scpf) not found."
  echo "Manual distribution of mpilc to the compute nodes is required"
  echo
  echo "Please ensure $INSTALL_DIR/mpilc is available on all nodes"
  echo "before running Link Checker."
fi

